ad_library {
	Procs needed to execute selenium tests.
}

namespace eval selenium {}

ad_proc selenium::location { } {
	Returns the location of selenium tests in the file system.
	We use this to find out where the tests are located.
} {
	set packagedir [acs_package_root_dir "selenium-test"]
	return "${packagedir}/www/tests"
}

ad_proc selenium::create_blank { 
	-suite_name
	{-pretty_name ""}
} {
	Creates an empty test suite.
	Returns the id of the new testsuite, if successful.
	Returns 0 if the process failed.	
} {
	if { ![db_0or1row "testexists" "select suite_name from selenium_testsuites where suite_name = :suite_name"] } {
		db_transaction {
			db_dml "insertsuite" "insert into selenium_testsuites (suite_name,pretty_name) values (:suite_name, :pretty_name)"
		} on_error {
			# TODO : add appropriate error handling here
			return 0
		}
		# create the directory
		set location [selenium::location]
		if { ![file isdirectory "${location}/${suite_name}"] } {
			file mkdir "${location}/${suite_name}"
		}
		set id [db_string "getid" "select id from selenium_testsuites where suite_name =:suite_name"]
		return $id
	}
	return 0
}

ad_proc selenium::file_count {
	-id
} {
	Returns 0 if the directory for the test suite is empty.
	Returns the number of files in the directory if folder is not empty.
	Returns -1 if an error occurred or if the directory does not exist.
} {
	set location [selenium::location]
	if { [db_0or1row "getname" "select suite_name from selenium_testsuites where id=:id"] } {
		set count 0
		foreach file [exec ls "${location}/${suite_name}"] {
			incr count
		}
		return $count
	} else {
		return -1
	}
}

ad_proc selenium::genonetestsuite {
	-dir
} {
	Generates a selenium test suite html file from the tests files in the given directory.
} {
	# locate selenium test folder
	set location [selenium::location]
	if { [file isdirectory "${location}/${dir}"] } {
			set testsuite "
			<html>
			<head>
			<meta content=\"text/html; charset=ISO-8859-1\" http-equiv=\"content-type\">
			<title>$dir</title>
			
			</head>
			
				<table cellpadding=\"1\" cellspacing=\"1\" border=\"1\">
				<tbody>
					<tr><td></td></tr>\n"

			# loop thru the files in the given directory
			foreach testfile [exec ls "${location}/${dir}"] {
				append testsuite "<tr><td><a href=\"${dir}/${testfile}\">$testfile</a></td></tr>\n"
			}

			append testsuite "
				</tbody>
				</table>
			
			</body>
			</html>
			"

			# create the test suite file
			if { ${dir} != "setup"} {
				set testsuitefile "${location}/testsuite-${dir}.html"
				if { ![file exists $testsuitefile] } {
					exec touch $testsuitefile
				} else {
					exec rm $testsuitefile
				}
				set fileId [open $testsuitefile "w"]
				puts -nonewline $fileId $testsuite
				close $fileId
				if { ![db_0or1row "testexists" "select suite_name from selenium_testsuites where suite_name = :dir"] } {
					db_dml "insertsuite" "insert into selenium_testsuites (suite_name) values (:dir)"
				}
			}
	}
}

ad_proc selenium::genalltestsuites {} {
	Reads the folders inside the tests folder in selenium.
	Reads the files inside each folder and generates one test suite per folder.
} {
	# locate selenium test folder
	set location [selenium::location]
	# get the contents of the selenium test folder
	# loop thru the results and get the directories
	# store them in a list
	foreach dir [exec ls $location] {
		selenium::genonetestsuite -dir ${dir}
	}
}